@@ -20,6 +20,8 @@
 
 
 #include "buddies/buddy-preferred-manager.h"
+#include "chat/type/chat-type-contact.h"
+#include "chat/type/chat-type-contact-set.h"
 
 #include "api.h"
 
@@ -111,3 +113,15 @@ QList<Account> Api::accountsOfBuddy( Buddy buddy )
 	}
 	return accountslist;
 }
+
+
+Chat Api::findChatForContactOrContactSet( ContactSet contactset, NotFoundAction notfoundaction )
+{
+	if( contactset.count() < 1 )
+		return Chat::null;
+
+	if( contactset.count() == 1 )
+		return ChatTypeContact::findChat( contactset.toContact(), notfoundaction );
+
+	return ChatTypeContactSet::findChat( contactset, notfoundaction );
+}
