@@ -73,7 +73,7 @@ void GlobalWidgetManager::inactivitytimerTimeout()
 {
 	if( ! WIDGET->isVisible() )
 		return;
-	if( ! _isActiveWindow( WIDGET ) )
+	if( shouldClose( WIDGET ) )
 	{
 		WIDGET->close();
 		return;
@@ -82,6 +82,23 @@ void GlobalWidgetManager::inactivitytimerTimeout()
 }
 
 
+bool GlobalWidgetManager::shouldClose( QWidget *widget )
+{
+	foreach( QObject *child, widget->children() )
+	{
+		QWidget *widget = dynamic_cast<QWidget*>( child );
+		if( ! widget )
+			continue;
+		if( ! widget->isWindow() )
+			continue;
+		if( ! widget->isVisible() )
+			continue;
+		return false;
+	}
+	return ( ! _isActiveWindow( widget ) );
+}
+
+
 void GlobalWidgetManager::widgetDestroyed()
 {
 	stop();
