@@ -185,7 +185,7 @@
     </message>
     <message>
         <source>Add new menu ...</source>
-        <translation>Aggiungi nuovo menù</translation>
+        <translation>Aggiungi nuovo menù ...</translation>
     </message>
     <message numerus="yes">
         <source>%n hotkey(s):
@@ -224,5 +224,13 @@ sono in uso da un&amp;apos;altra applicazione.</numerusform>
         <source>Sort by status</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Multilogon window</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Always show contact&apos;s identifier</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 </TS>
