@@ -227,5 +227,13 @@ jest używanch przez inną aplikację.</numerusform>
         <source>Sort by status</source>
         <translation>Uwzględniaj status przy sortowaniu</translation>
     </message>
+    <message>
+        <source>Multilogon window</source>
+        <translation>Okno multilogowania</translation>
+    </message>
+    <message>
+        <source>Always show contact&apos;s identifier</source>
+        <translation>Zawsze wyświetlaj identyfikator kontaktu</translation>
+    </message>
 </context>
 </TS>
