@@ -20,14 +20,14 @@ int KaduCompletion::KaduCompletionPlugin::init(bool firstLoad)
 {
 	Q_UNUSED(firstLoad)
 
-	KaduCompletion::KaduCompletion::createInstance();
+	KaduCompletion::createInstance();
 
 	return 0;
 }
 
 void KaduCompletion::KaduCompletionPlugin::done()
 {
-	KaduCompletion::KaduCompletion::destroyInstance();
+	KaduCompletion::destroyInstance();
 }
 
 Q_EXPORT_PLUGIN2(kadu_completion, KaduCompletion::KaduCompletionPlugin)
